@@ -2,14 +2,11 @@
 # Distributed under the terms of the MIT License.
 # SPDX-License-Identifier: MIT
 #
-# This code is part of the package: Antarctic-plots (https://github.com/mdtanker/antarctic_plots)
+# This code is part of the package:
+# Antarctic-plots (https://github.com/mdtanker/antarctic_plots)
 #
 """Functions to automate Antarctic data visualization"""
 
 from importlib.metadata import version
 
-from antarctic_plots import profile
-from antarctic_plots import fetch
-from antarctic_plots import utils
-
 __version__ = version("antarctic_plots")
